// Demo 8

//             Sally's Lemonade Stand
//           A Screen Based Application
//  A Reading and Processing Up to a Stopping Signal
//         and Keeping a Running Total Demo
//
//           by Charles W. Neville, 1998
//        Copyright Charles W. Neville, 1998

// Scenario: Little Sally is a very precocious five year old.  She admires
// you (her older brother or sister) very much, and so she asks you to
// write a program to keep track of her daily sales receipts.  Although
// she is quite good at addition, she wants to simply enter each sale
// into her Notebook computer and at the end of the day see the number
// of sales and the total sales for the day.  She agrees to enter -999
// to indicate that the days sales are finished, and to tell her computer
// to print the totals.
//
// This is your first effort.  It is a purely screen based application.

import java.io.*;  // have to import Java's IO (Input/Output) classes to
                   // read from the keyboard, or to do any kind of file 
                   // based IO.

class Sally {

   public static void main( String args[] ) throws IOException {

     // this is a screen based application, so we don't need to construct
     // an instance of ourselves, PROVIDED that all methods are declared
     // as static, and all main program variables are defined inside method
     // main (or declared as static).

     final int stoppingSignal = -999;  // our first constant declaration.
                        // final means its value cannot be changed.
                        // A stopping signal (sentinel) should always have
                        // a value impossible or unlikely to occur in
                        // real data.  -999 is a favorite.

     int salePrice, count, total;  // we don't want final here because
                      // these are variables (their values can change).

     // Abracadabra! Arcane stuff needed to deal with screen-keyboard based
     // input.  Just accept it for the time being.  Basically, what this
     // does is open the keyboard as a special kind of file (stream) which
     // is particularly easy to read from.  Treat the "throws IOException"
     // clause in the declaration of main the same way, just accept it for
     // the time being as needed whenever you do keyboard based input in
     // a screen based application, or read from a file.
     BufferedReader stdin;
     stdin = new BufferedReader( new InputStreamReader( System.in ) );

     // Now begin the code to read little Sally's salesPrices and total
     // up the day's sales.       

     // initializations
     count = 0;
     total = 0;  // always initialize total to 0 when keeping a running total

     // always read first data item outside while loop when reading and
     // processing up to a stopping signal (using a sentinel to mark the
     // end of data).
     // issue a screen prompt
     System.out.print("Enter first sale amount and press Enter key > ");
     System.out.flush();  // force system to write prompt to screen.  Not
                          // flushing after a print lets the system write
                          // to the screen whenever it pleases, which may
                          // be only after program has ended!  So ALWAYS
                          // FLUSH AFTER USING PRINT.
     salePrice = Integer.parseInt( stdin.readLine() );  // read first data item
     // now enter the main while loop.  Process the current data item, 
     // then read the next data item.
     while (salePrice != stoppingSignal) {

        // process data item by updating total and count
        total = total + salePrice;
        count = count + 1;

        // read next data item
        System.out.print("Enter next sale amount and press Enter key > ");
        salePrice = Integer.parseInt( stdin.readLine() );
     }

     // when we get here, Little Sally has entered the -999 stoppingSignal
     // for the sale price, so we have exited the while loop, and it is
     // time for us to print the days totals.
     System.out.println( "Total sales today were: " + total );  // no
                 // need to flush after a println, done automatically,
                 // only need to flush after a print.
     System.out.println( "Total number sales today were: " + count );
     System.out.println("You did a good job selling lemonade today, Sally!");
   }
}





